PypiMonitor — Monitor your pypi packages
========================================

|sources| |pypi| |build| |documentation| |license|

An HTML dashboard to monitor your `PyPI packages <http://pypi.python.org>`_. It
displays a line charts showing the evolution of downloads across versions, and
a set of badges (download statistics, `readthedocs <http://readthedocs.io>`__ badge,
continuous integration, etc.). See the example below.

|example|

It is available as a `command line interface
<http://pypimonitor.readthedocs.io/en/latest/module#pypimonitor-httpd>`_ that
generates the HTML code, and as a `web server
<http://pypimonitor.readthedocs.io/en/latest/module#pypimonitor-httpd>`_, to
generate and serve this dashboard.

What's new?
-----------

See `changelog
<http://framagit.org/spalax/pypimonitor/blob/master/CHANGELOG.md>`_.

What's next?
------------

This package replaces a static page that I manually updated from times to times. It does what I need, so there is little chance that I will develop it further. However, I see two directions this project could take:

- break everything, remove every single line of python code, and rewrite everything in javascript, so that this can be served as a static page (from the server point of view) that can be published using github pages, readthedocs, etc., and conquer the world;
- or replace this quick and dirty web server using `your favorite web framework <http://wiki.python.org/moin/WebFrameworks>`_, cache requests to the pypi API, publish it somewhere, and conquer the world.

I will do neither. But if you want to, you have my blessing… :)

Download and install
--------------------

* From sources:

  * Download: https://pypi.python.org/pypi/pypimonitor
  * Install (in a `virtualenv`, if you do not want to mess with your distribution installation system)::

        python3 setup.py install

* From pip::

    pip install pypimonitor

* Quick and dirty Debian (and Ubuntu?) package

  This requires `stdeb <https://github.com/astraw/stdeb>`_ to be installed::

      python3 setup.py --command-packages=stdeb.command bdist_deb
      sudo dpkg -i deb_dist/pypimonitor-<VERSION>_all.deb

Documentation
-------------

* The compiled documentation is available on `readthedocs
  <http://pypimonitor.readthedocs.io>`_

* To compile it from source, download and run::

      cd doc && make html


.. |documentation| image:: http://readthedocs.org/projects/pypimonitor/badge
  :target: http://pypimonitor.readthedocs.io
.. |pypi| image:: https://img.shields.io/pypi/v/pypimonitor.svg
  :target: http://pypi.python.org/pypi/pypimonitor
.. |license| image:: https://img.shields.io/pypi/l/pypimonitor.svg
  :target: http://www.gnu.org/licenses/agpl-3.0.html
.. |sources| image:: https://img.shields.io/badge/sources-pypimonitor-brightgreen.svg
  :target: http://git.framasoft.org/spalax/pypimonitor
.. |build| image:: https://git.framasoft.org/spalax/pypimonitor/badges/master/build.svg
  :target: https://git.framasoft.org/spalax/pypimonitor/builds
.. |example| image:: http://pypimonitor.readthedocs.io/en/latest/_static/spalax.png
  :target: http://pypimonitor.readthedocs.io/en/latest/_static/spalax.html

